@@ -112,8 +112,8 @@ If you commit the changes to Git each time after running `pj`, you can easily co
 
 ### Write CDK Construct
 
-1. Write a simple CDK construct in [src/index.ts](src/index.ts).
-   There are already great tutorials (like [cdkworkshop.com](https://cdkworkshop.com/) available on how to write constructs.
+1. Write a simple CDK construct in `src/index.ts`.
+   There are already great tutorials like [cdkworkshop.com](https://cdkworkshop.com/) available about how to write constructs.
    Here's a small code snippet for a simple Lambda function using inline code:
 
    ```python
@@ -126,7 +126,7 @@ If you commit the changes to Git each time after running `pj`, you can easily co
    )
    ```
 
-   Have a look at [index.ts](src/index.ts) for all the details.
+   Have a look at [LambdaConstruct.ts](src/index.ts) for an examples construct that declares various Lambda functions.
    Instead of using a Lambda function, you can also use whatever you like.
 2. Write a simple test for this construct in [test/index.test.ts](test/index.test.ts).
    Here's also a small code snippet which ensures that our Lambda function is created in the stack:
@@ -137,7 +137,7 @@ If you commit the changes to Git each time after running `pj`, you can easily co
          const app = new cdk.App();
          const stack = new cdk.Stack(app, 'TestStack');
 
-         new InlineLambdaConstruct(stack, 'SimpleInlineLambdaConstruct');
+         new LambdaConstruct(stack, 'SimpleInlineLambdaConstruct');
 
          expectCDK(stack).to(countResources('AWS::Lambda::Function', 1));
        })
@@ -407,23 +407,123 @@ from ._jsii import *
 import aws_cdk.core
 
 
-class InlineLambdaConstruct(
+class ConstructWithProperties(
     aws_cdk.core.Construct,
     metaclass=jsii.JSIIMeta,
-    jsii_type="@seeebiii/projen-test.InlineLambdaConstruct",
+    jsii_type="@seeebiii/projen-test.ConstructWithProperties",
 ):
-    '''A simple CDK construct to create a Lambda function with static inline code that prints the event and calls the callback function.'''
+    '''A simple CDK construct illustrating the differences in declaring construct properties with interfaces.'''
+
+    def __init__(
+        self,
+        parent: aws_cdk.core.Construct,
+        name: builtins.str,
+        props: "StructProperties",
+        props2: "IBehaviorProperties",
+    ) -> None:
+        '''
+        :param parent: -
+        :param name: -
+        :param props: -
+        :param props2: -
+        '''
+        jsii.create(ConstructWithProperties, self, [parent, name, props, props2])
+
+
+@jsii.interface(jsii_type="@seeebiii/projen-test.IBehaviorProperties")
+class IBehaviorProperties(typing_extensions.Protocol):
+    '''This is a *behavioral interface* identified by ``I`` in its name.
+
+    It will be translated to a "regular" interface which needs to be implemented.
+    You can also use methods here, e.g. ``doSth(): void;``.
+
+    :see: https://aws.github.io/jsii/user-guides/lib-author/typescript-restrictions/#interfaces
+    '''
+
+    @builtins.staticmethod
+    def __jsii_proxy_class__() -> typing.Type["_IBehaviorPropertiesProxy"]:
+        return _IBehaviorPropertiesProxy
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="otherProp")
+    def other_prop(self) -> builtins.str:
+        ...
+
+
+class _IBehaviorPropertiesProxy:
+    '''This is a *behavioral interface* identified by ``I`` in its name.
+
+    It will be translated to a "regular" interface which needs to be implemented.
+    You can also use methods here, e.g. ``doSth(): void;``.
+
+    :see: https://aws.github.io/jsii/user-guides/lib-author/typescript-restrictions/#interfaces
+    '''
+
+    __jsii_type__: typing.ClassVar[str] = "@seeebiii/projen-test.IBehaviorProperties"
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="otherProp")
+    def other_prop(self) -> builtins.str:
+        return typing.cast(builtins.str, jsii.get(self, "otherProp"))
+
+
+class LambdaConstruct(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@seeebiii/projen-test.LambdaConstruct",
+):
+    '''A CDK construct to create Lambda functions.'''
 
     def __init__(self, parent: aws_cdk.core.Construct, name: builtins.str) -> None:
         '''
         :param parent: -
         :param name: -
         '''
-        jsii.create(InlineLambdaConstruct, self, [parent, name])
+        jsii.create(LambdaConstruct, self, [parent, name])
+
+
+@jsii.data_type(
+    jsii_type="@seeebiii/projen-test.StructProperties",
+    jsii_struct_bases=[],
+    name_mapping={"my_prop": "myProp"},
+)
+class StructProperties:
+    def __init__(self, *, my_prop: builtins.str) -> None:
+        '''This interface is translated into a *struct* containing data.
+
+        E.g. if translated to Java, an interface ``StructProperties`` is created containing a builder subclass to create an instance of the interface.
+
+        :param my_prop: 
+
+        :see: https://aws.github.io/jsii/user-guides/lib-author/typescript-restrictions/#interfaces
+        '''
+        self._values: typing.Dict[str, typing.Any] = {
+            "my_prop": my_prop,
+        }
+
+    @builtins.property
+    def my_prop(self) -> builtins.str:
+        result = self._values.get("my_prop")
+        assert result is not None, "Required property 'my_prop' is missing"
+        return typing.cast(builtins.str, result)
+
+    def __eq__(self, rhs: typing.Any) -> builtins.bool:
+        return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+    def __ne__(self, rhs: typing.Any) -> builtins.bool:
+        return not (rhs == self)
+
+    def __repr__(self) -> str:
+        return "StructProperties(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
-    "InlineLambdaConstruct",
+    "ConstructWithProperties",
+    "IBehaviorProperties",
+    "LambdaConstruct",
+    "StructProperties",
 ]
 
 publication.publish()
